# probability-calculator

Calculate with and analyze probability densities.

More description will be added soon™.

## Contributing
We greatly appreciate fixes and new features for [probability-calculator](https://github.com/HendrikRoehm/probability-calculator). All contributions to this project should be sent as pull requests on github.

## License

[Apache License 2.0](LICENSE)
